==> apache-parquet-1.10.1.tar.gz: apache-parquet-1.10.1/parquet-avro/src/test/java/org/apache/parquet/avro/TestAvroDataSupplier.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.parquet.avro;

import org.apache.avro.generic.GenericData;
import org.apache.hadoop.conf.Configuration;
import org.junit.Assert;
import org.junit.Test;

public class TestAvroDataSupplier {

  public static class GenericDataSupplier implements AvroDataSupplier {
    @Override
    public GenericData get() {
      return GenericData.get();
    }
  }

  @Test
  public void testSetSupplierMethod() {
    Configuration conf = new Configuration(false);
    AvroReadSupport.setAvroDataSupplier(conf, GenericDataSupplier.class);
    Assert.assertEquals("Should contain the class name",
        "org.apache.parquet.avro.TestAvroDataSupplier$GenericDataSupplier",
        conf.get(AvroReadSupport.AVRO_DATA_SUPPLIER));
  }
}

==> apache-parquet-1.15.2.tar.gz: apache-parquet-1.15.2/parquet-avro/src/test/java/org/apache/parquet/avro/TestAvroDataSupplier.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.parquet.avro;

import org.apache.avro.generic.GenericData;
import org.apache.hadoop.conf.Configuration;
import org.junit.Assert;
import org.junit.Test;

public class TestAvroDataSupplier {

  public static class GenericDataSupplier implements AvroDataSupplier {
    @Override
    public GenericData get() {
      return GenericData.get();
    }
  }

  @Test
  public void testSetSupplierMethod() {
    Configuration conf = new Configuration(false);
    AvroReadSupport.setAvroDataSupplier(conf, GenericDataSupplier.class);
    Assert.assertEquals(
        "Should contain the class name",
        "org.apache.parquet.avro.TestAvroDataSupplier$GenericDataSupplier",
        conf.get(AvroReadSupport.AVRO_DATA_SUPPLIER));
  }
}
